#=============================================================================
# Copyright 2014 Luís Pereira <luis.artur.pereira@gmail.com>
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. The name of the author may not be used to endorse or promote products
#    derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#=============================================================================
#
# These functions enables "automatic" translation loading in Nde Qt5 apps
#   and libs. They generate a .cpp file that takes care of everything. The
#   user doesn't have to do anything in the source code.
#
# Typical use:
#   include(NdeTranslationLoader)
#   nde_app_translation_loader(nde-app_QM_LOADER ${PROJECT_NAME})
#   add_executable(${PROJECT_NAME}
#       ${nde-app_QM_LOADER}
#       ...
#   )


# nde_app_translation_loader(<source_files> <catalog_name>)
#       <source_files> The generated .cpp file is added to <source_files>
#       <catalog_name> Translations catalog to be loaded
function(nde_app_translation_loader source_files catalog_name)
    configure_file(
        ${NDE_CMAKE_MODULES_DIR}/NdeAppTranslationLoader.cpp.in
        NdeAppTranslationLoader.cpp @ONLY
    )
    set(${source_files} ${${source_files}} ${CMAKE_CURRENT_BINARY_DIR}/NdeAppTranslationLoader.cpp PARENT_SCOPE)
endfunction()

# nde_lib_translation_loader(<source_files> <catalog_name>)
#       <source_files> The generated .cpp file is added to <source_files>
#       <catalog_name> Translations catalog to be loaded
function(nde_lib_translation_loader source_files catalog_name)
    configure_file(
        ${NDE_CMAKE_MODULES_DIR}/NdeLibTranslationLoader.cpp.in
        NdeLibTranslationLoader.cpp @ONLY
    )
    set(${source_files} ${${source_files}} ${CMAKE_CURRENT_BINARY_DIR}/NdeLibTranslationLoader.cpp PARENT_SCOPE)
endfunction()

# nde_plugin_translation_loader(<source_files> <catalog_name>)
#       <source_files> The generated .cpp file is added to <source_files>
#       <catalog_name> Translations catalog to be loaded
#       <plugin_type> Plugin type. Example: nde-panel
function(nde_plugin_translation_loader source_files catalog_name plugin_type)
    configure_file(
        ${NDE_CMAKE_MODULES_DIR}/NdePluginTranslationLoader.cpp.in
        NdePluginTranslationLoader.cpp @ONLY
    )
    set(${source_files} ${${source_files}} ${CMAKE_CURRENT_BINARY_DIR}/NdePluginTranslationLoader.cpp PARENT_SCOPE)
endfunction()
